@@ -1,9 +1,9 @@
 package Calendar::Indonesia::Holiday;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-01-13'; # DATE
+our $DATE = '2021-01-14'; # DATE
 our $DIST = 'Calendar-Indonesia-Holiday'; # DIST
-our $VERSION = '0.332'; # VERSION
+our $VERSION = '0.333'; # VERSION
 
 use 5.010001;
 use strict;
@@ -37,18 +37,21 @@ my @fixed_holidays = (
         ind_name   => "Tahun Baru",
         eng_name   => "New Year",
         tags       => [qw/international/],
+        fixed_date => 1,
     },
     my $indep = {
         day        => 17, month =>  8,
         ind_name   => "Proklamasi",
         eng_name   => "Declaration Of Independence",
         tags       => [qw/national/],
+        fixed_date => 1,
     },
     my $christmas = {
         day        => 25, month => 12,
         ind_name   => "Natal",
         eng_name   => "Christmas",
         tags       => [qw/international religious religion=christianity/],
+        fixed_date => 1,
     },
     my $labord = {
         day         => 1, month => 5,
@@ -59,17 +62,19 @@ my @fixed_holidays = (
         decree_date => "2013-04-29",
         decree_note => "Labor day becomes national holiday since 2014, ".
             "decreed by president",
+        fixed_date  => 1,
     },
     my $pancasilad = {
         day         => 1, month => 6,
         year_start  => 2017,
         ind_name    => "Hari Lahir Pancasila",
         eng_name    => "Pancasila Day",
-        tags       => [qw/national/],
+        tags        => [qw/national/],
         decree_date => "2016-06-01",
         decree_note => "Pancasila day becomes national holiday since 2017, ".
             "decreed by president (Keppres 24/2016)",
         # ref: http://www.kemendagri.go.id/media/documents/2016/08/03/k/e/keppres_no.24_th_2016.pdf
+        fixed_date  => 1,
     },
 );
 
@@ -91,6 +96,7 @@ sub _h_chnewyear {
     $r->{ind_aliases} = [];
     $r->{eng_aliases} = [];
     $r->{is_holiday}  = 1;
+    $r->{year_start}  = 2003; # decreed in 2002 by megawati soekarnoputri
     $r->{tags}        = [qw/international calendar=lunar/];
     ($r);
 }
@@ -292,6 +298,42 @@ sub _expand_dm {
 
 my %year_holidays;
 
+# decreed ?
+# source: https://id.wikipedia.org/wiki/2000
+{
+    $year_holidays{2000} = [
+        _h_eidulf    ({_expand_dm("08-01")}, {hyear=>1420, day=>1}),
+        _h_eidulf    ({_expand_dm("09-01")}, {hyear=>1420, day=>2}),
+        _h_eidula    ({_expand_dm("16-03")}, {hyear=>1420}),
+        _h_nyepi     ({_expand_dm("04-04")}, {hyear=>1922}),
+        _h_hijra     ({_expand_dm("06-04")}, {hyear=>1421}),
+        _h_goodfri   ({_expand_dm("21-04")}),
+        _h_vesakha   ({_expand_dm("18-05")}, {hyear=>2544}),
+        _h_ascension ({_expand_dm("01-06")}),
+        _h_mawlid    ({_expand_dm("15-06")}, {hyear=>1421}),
+        _h_isramiraj ({_expand_dm("25-10")}, {hyear=>1421}),
+        _h_eidulf    ({_expand_dm("16-12")}, {hyear=>1422, day=>1}),
+        _h_eidulf    ({_expand_dm("17-12")}, {hyear=>1422, day=>2}),
+    ];
+}
+
+# decreed ?
+# source: https://id.wikipedia.org/wiki/2001
+{
+    $year_holidays{2001} = [
+        _h_eidula    ({_expand_dm("05-03")}, {hyear=>1421}),
+        _h_nyepi     ({_expand_dm("25-03")}, {hyear=>1923}),
+        _h_hijra     ({_expand_dm("26-03")}, {hyear=>1422}),
+        _h_goodfri   ({_expand_dm("13-04")}),
+        _h_vesakha   ({_expand_dm("07-05")}, {hyear=>2545}),
+        _h_ascension ({_expand_dm("24-05")}),
+        _h_mawlid    ({_expand_dm("04-06")}, {hyear=>1422}),
+        _h_isramiraj ({_expand_dm("15-10")}, {hyear=>1422}),
+        _h_eidulf    ({_expand_dm("16-12")}, {hyear=>1422, day=>1}),
+        _h_eidulf    ({_expand_dm("17-12")}, {hyear=>1422, day=>2}),
+    ];
+}
+
 # decreed ?
 {
     my $eidulf2002;
@@ -304,10 +346,10 @@ my %year_holidays;
         _h_ascension ({_expand_dm("09-05")}),
         _h_mawlid    ({_expand_dm("25-05")}, {hyear=>1423, original_date=>'2003-05-14'}),
         _h_vesakha   ({_expand_dm("26-05")}, {hyear=>2546}),
-        _h_isramiraj ({_expand_dm("04-10")}),
+        _h_isramiraj ({_expand_dm("04-10")}, {hyear=>1423}),
         ($eidulf2002 =
-        _h_eidulf    ({_expand_dm("06-12")}, {hyear=>1424, day=>1})),
-        _h_eidulf    ({_expand_dm("07-12")}, {hyear=>1424, day=>2}),
+        _h_eidulf    ({_expand_dm("06-12")}, {hyear=>1423, day=>1})),
+        _h_eidulf    ({_expand_dm("07-12")}, {hyear=>1423, day=>2}),
 
         _jointlv     ({_expand_dm("05-12")}, {holiday=>$eidulf2002}),
         _jointlv     ({_expand_dm("09-12")}, {holiday=>$eidulf2002}),
@@ -330,8 +372,8 @@ my %year_holidays;
         _h_ascension ({_expand_dm("30-05")}, {original_date=>'2003-05-29'}),
         _h_isramiraj ({_expand_dm("22-09")}, {original_date=>'2003-09-24'}),
         ($eidulf2003 =
-        _h_eidulf    ({_expand_dm("25-11")}, {hyear=>1425, day=>1})),
-        _h_eidulf    ({_expand_dm("26-11")}, {hyear=>1425, day=>2}),
+        _h_eidulf    ({_expand_dm("25-11")}, {hyear=>1424, day=>1})),
+        _h_eidulf    ({_expand_dm("26-11")}, {hyear=>1424, day=>2}),
 
         _jointlv     ({_expand_dm("24-11")}, {holiday=>$eidulf2003}),
         _jointlv     ({_expand_dm("27-11")}, {holiday=>$eidulf2003}),
@@ -1312,7 +1354,7 @@ Calendar::Indonesia::Holiday - List Indonesian public holidays
 
 =head1 VERSION
 
-This document describes version 0.332 of Calendar::Indonesia::Holiday (from Perl distribution Calendar-Indonesia-Holiday), released on 2021-01-13.
+This document describes version 0.333 of Calendar::Indonesia::Holiday (from Perl distribution Calendar-Indonesia-Holiday), released on 2021-01-14.
 
 =head1 SYNOPSIS
 
@@ -1404,7 +1446,7 @@ days*. If work_saturdays is set to true, Saturdays are also counted as working
 days. If observe_joint_leaves is set to false, joint leave days are also counted
 as working days.
 
-Contains data from years 2002 to 2021 (joint leave days until
+Contains data from years 2000 to 2021 (joint leave days until
 2021).
 
 This function is not exported by default, but exportable.
@@ -1464,7 +1506,7 @@ days*. If work_saturdays is set to true, Saturdays are also counted as working
 days. If observe_joint_leaves is set to false, joint leave days are also counted
 as working days.
 
-Contains data from years 2002 to 2021 (joint leave days until
+Contains data from years 2000 to 2021 (joint leave days until
 2021).
 
 This function is not exported by default, but exportable.
@@ -1576,7 +1618,7 @@ List Indonesian holidays in calendar.
 
 List holidays and joint leave days ("cuti bersama").
 
-Contains data from years 2002 to 2021 (joint leave days until
+Contains data from years 2000 to 2021 (joint leave days until
 2021).
 
 This function is not exported by default, but exportable.
@@ -2042,14 +2084,34 @@ Return value:  (any)
 
 =head2 What is "joint leave"?
 
-Workers are normally granted 12 days of paid leave per year. They are free to
-spend it on whichever days they want. The joint leave ("cuti bersama") is a
-government program of recent years (since 2002) to recommend that some of these
-leave days be spent together nationally on certain days, especially during
-Lebaran (Eid Ul-Fitr). It is not mandated, but many do follow it anyway, e.g.
-government civil workers, banks, etc. I am marking joint leave days with
-is_joint_leave=1 and is_holiday=0, while the holidays themselves with
-is_holiday=1, so you can differentiate/select both/either one.
+Workers are normally granted around 12 days of paid leave per year (excluding
+special leaves like maternity, etc). They are free to spend them on whichever
+days they want. The joint leave ("cuti bersama") is a government program to
+recommend that some of these leave days be spent together nationally on certain
+assigned days, especially adjacent to holidays like Eid Ul-Fitr ("Lebaran"). It
+is not mandated (companies can opt to follow it or not, depending on their
+specific situation), but many do follow it anyway, e.g. government civil
+workers, banks, etc. I am marking joint leave days with is_joint_leave=1 and
+is_holiday=0, while the holidays themselves with is_holiday=1, so you can
+differentiate/select both/either one.
+
+=head2 When was joint leave established?
+
+Joint leave was first decreed in 2001 [1] for the 2002 & 2003 calendar years.
+The 2001 calendar year does not yet have joint leave days [2]. See also [3].
+Websites that list joint leave days for 2001 or earlier years (example: [4],
+[5]) are incorrect; by 2001 or earlier, these joint leave days had not been
+officially decreed by the government.
+
+[1] https://jdih.kemnaker.go.id/data_wirata/2002-4-4.pdf
+
+[2] https://peraturan.bkpm.go.id/jdih/userfiles/batang/Kepmenag_162_2000.pdf
+
+[3] http://www.wikiapbn.org/cuti-bersama/
+
+[4] https://kalenderindonesia.com/libur/masehi/2001
+
+[5] https://kalenderindonesia.com/libur/masehi/1991
 
 =head2 Holidays before 2002?
 
